# 1.2.0

- Added `extra-imports` support to Prismarine
- Added `version` command

## 1.1.0

- Prismarine support
- Added `delete` command
- Added `cleanup` command
- Added `inspect` command

## 1.0.0

- First published version
